@@ -12,17 +12,18 @@ from .types.pypi_entry import PypiEntry
 from .user_config import read_oauth_token
 
 
-def get_all_pkg_names() -> Iterator[str]:   
+@cache.memoize()
+def get_all_pkg_names() -> Iterator[str]:
     tree: html.HtmlElement = html.fromstring(_get_all_pkgs_html())
     return tree.xpath('//a/text()')
 
 
 @cache.memoize()
-def get_top_pupular_pkg_names() -> Set[str]:
-    logging.debug('get_top_pupular_pkg_names')
+def get_top_popular_pkg_names() -> Set[str]:
+    logging.debug('get_top_popular_pkg_names')
     response = requests.get('https://hugovk.github.io/top-pypi-packages/top-pypi-packages-365-days.min.json')
     response.raise_for_status()
-    return {r['project'] for r in response.json().get('rows', [])}    
+    return {r['project'] for r in response.json().get('rows', [])}
 
 
 @cache.memoize()
@@ -30,7 +31,7 @@ def _get_all_pkgs_html() -> str:
     logging.debug('get_all_pkgs_html')
     response = requests.get("https://pypi.org/simple/")
     response.raise_for_status()
-    return response.text 
+    return response.text
 
 
 @cache.memoize()
@@ -38,11 +39,11 @@ def get_pkg_pypi_entry(pkg_name: str) -> PypiEntry:
     logging.debug(f'get_pkg_pypi_entry for {pkg_name}')
     response = requests.get(f'https://pypi.org/pypi/{pkg_name}/json')
     response.raise_for_status()
-    return PypiEntry(**response.json())    
+    return PypiEntry(**response.json())
 
 
 @cache.memoize()
-def get_pkg_stats(pkg_name: str, last_days: int = 90) -> PackageStats:
+def get_pkg_stats(pkg_name: str) -> PackageStats:
     logging.debug(f'get_pkg_stats for {pkg_name}')
     url = 'https://api.pepy.tech/api/v2/projects/' + pkg_name
     response = requests.get(url)
